==> gammaray_2.4.0.orig.tar.xz: gammaray-2.4.0/ui/uiintegration.cpp <==
/*
 * This file is part of GammaRay, the Qt application inspection and
 * manipulation tool.
 *
 * Copyright (C) 2014-2015 Klar?lvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 * Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 *
 * Licensees holding valid commercial KDAB GammaRay licenses may use this file in
 * accordance with GammaRay Commercial License Agreement provided with the Software.
 *
 * Contact info@kdab.com if any conditions of this licensing are not clear to you.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "uiintegration.h"

using namespace GammaRay;

UiIntegration* UiIntegration::s_uiIntegrationInstance = 0;

UiIntegration::UiIntegration(QObject *parent)
    : QObject(parent)
{
    Q_ASSERT(!s_uiIntegrationInstance);
    s_uiIntegrationInstance = this;
}

UiIntegration::~UiIntegration()
{
    s_uiIntegrationInstance = 0;
}

UiIntegration * UiIntegration::instance()
{
    return s_uiIntegrationInstance;
}

void UiIntegration::requestNavigateToCode(const QString& filePath, int lineNumber, int columnNumber)
{
    emit UiIntegration::instance()->navigateToCode(filePath, lineNumber, columnNumber);
}

==> gammaray_2.5.1.orig.tar.xz: gammaray-2.5.1/ui/uiintegration.cpp <==
/*
 * This file is part of GammaRay, the Qt application inspection and
 * manipulation tool.
 *
 * Copyright (C) 2014-2016 Klar?lvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 * Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 *
 * Licensees holding valid commercial KDAB GammaRay licenses may use this file in
 * accordance with GammaRay Commercial License Agreement provided with the Software.
 *
 * Contact info@kdab.com if any conditions of this licensing are not clear to you.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "uiintegration.h"

#include <QUrl>

using namespace GammaRay;

UiIntegration *UiIntegration::s_uiIntegrationInstance = 0;

UiIntegration::UiIntegration(QObject *parent)
    : QObject(parent)
{
    Q_ASSERT(!s_uiIntegrationInstance);
    s_uiIntegrationInstance = this;
}

UiIntegration::~UiIntegration()
{
    s_uiIntegrationInstance = 0;
}

UiIntegration *UiIntegration::instance()
{
    return s_uiIntegrationInstance;
}

void UiIntegration::requestNavigateToCode(const QUrl &url, int lineNumber, int columnNumber)
{
    if (UiIntegration::instance())
        emit UiIntegration::instance()->navigateToCode(url, lineNumber, columnNumber);
}
